%
%   MOTORTST.M  Set parameters and test out Simulink model of DC motor  
%               used in sun tracking servo mechanism
%
%   File prepared by J. R. White, UMass-Lowell (last update: Feb. 2020)
%

      clear all,   close all
%
%   MOTOR CHARACTERISTICS (usually given with spec sheet or measured)
%    Ra - Resistance of the motor armature (ohms)
%    La - Inductance of the motor armature (H)
%    kv - velocity constant (Vsec/rad)
%    kt - torque constant (Nm/A)
      Ra = 1.75;      La = 2.83e-3;      kv = 0.093;      kt = 0.0924;
%
%   SYSTEM CHARACTERISTICS 
%    Jeq - Inertia seen by the motor.  Includes inertia of the load. (kg m^2)
%    Beq   - Mechanical damping coefficient associated with rotation. (Nms)
      Jeq = 30.e-6;    Beq = 5.0e-3;
%
%   CASE 1: Overall transfer function from Fig. 6F.5 of documentation
      num = kt/(La*Jeq);
      den = [1  (Ra*Jeq + La*Beq)/(La*Jeq)  (Ra*Beq + kt*kv)/(La*Jeq)];
      sys1 = tf(num,den);
%
%   CASE 2: Extract linear model from SIMULINK graphical model
      motorsl     % displays Simulink model of motor
      [A,B,C,D] = linmod('motorsl');   sys2 = ss(A,B,C,D);
%
%   Determine step response of motor for both cases
      t = linspace(0,0.025,51);
      y1 = step(sys1,t);      y2 = step(sys2,t);
%
%   Plot time domain characteristics for both cases
      plot(t,y1,'ro',t,y2,'g-','LineWidth',2),grid
      xlabel('time (sec)'),ylabel('angular velocity (rad/sec)')
      title('Motor Response to Step Change in Applied Voltage')
      legend('Case 1: Transfer Function','Case 2: Simulink Model', ...
             'Location','SouthEast')
%
%   normal termination
